package Net::OAuth::LP::Models;

our $VERSION = '0.006'; # VERSION

use Moo::Role;
use Method::Signatures;

with('Net::OAuth::LP::Client');

1;

__END__

=head1 NAME

Net::OAuth::LP::Models - Base class for models

=head1 DESCRIPTION

Base Model Role

=cut
